summaryrefslogtreecommitdiffstats
path: root/kstars
diff options
context:
space:
mode:
Diffstat (limited to 'kstars')
-rw-r--r--kstars/README.i18n2
-rw-r--r--kstars/kstars/colorscheme.cpp20
-rw-r--r--kstars/kstars/deepskyobject.cpp2
-rw-r--r--kstars/kstars/detaildialog.cpp26
-rw-r--r--kstars/kstars/dms.cpp18
-rw-r--r--kstars/kstars/draglistbox.cpp2
-rw-r--r--kstars/kstars/draglistbox.h2
-rw-r--r--kstars/kstars/filesource.cpp2
-rw-r--r--kstars/kstars/finddialog.h2
-rw-r--r--kstars/kstars/fitsimage.cpp4
-rw-r--r--kstars/kstars/fitsviewer.cpp18
-rw-r--r--kstars/kstars/fovdialog.cpp2
-rw-r--r--kstars/kstars/indi/LICENSE2
-rw-r--r--kstars/kstars/indi/fitsrw.c14
-rw-r--r--kstars/kstars/indi/indiserver.c2
-rw-r--r--kstars/kstars/indidevice.cpp4
-rw-r--r--kstars/kstars/indidriver.cpp18
-rw-r--r--kstars/kstars/indielement.cpp4
-rw-r--r--kstars/kstars/indimenu.cpp2
-rw-r--r--kstars/kstars/indiproperty.cpp8
-rw-r--r--kstars/kstars/indistd.cpp2
-rw-r--r--kstars/kstars/infoboxes.cpp26
-rw-r--r--kstars/kstars/kscomet.cpp4
-rw-r--r--kstars/kstars/ksnewstuff.cpp2
-rw-r--r--kstars/kstars/kspopupmenu.cpp2
-rw-r--r--kstars/kstars/kstarsactions.cpp4
-rw-r--r--kstars/kstars/kstarsdata.cpp80
-rw-r--r--kstars/kstars/kstarsdata.h6
-rw-r--r--kstars/kstars/kstarsdcop.cpp10
-rw-r--r--kstars/kstars/kstarsinit.cpp4
-rw-r--r--kstars/kstars/locationdialog.cpp2
-rw-r--r--kstars/kstars/main.cpp6
-rw-r--r--kstars/kstars/objectnamelist.cpp4
-rw-r--r--kstars/kstars/objectnamelist.h4
-rw-r--r--kstars/kstars/opscatalog.cpp2
-rw-r--r--kstars/kstars/opscolors.cpp12
-rw-r--r--kstars/kstars/skymapdraw.cpp2
-rw-r--r--kstars/kstars/skyobject.cpp16
-rw-r--r--kstars/kstars/skypoint.cpp2
-rw-r--r--kstars/kstars/telescopewizardprocess.cpp2
-rw-r--r--kstars/kstars/thumbnaileditor.cpp2
-rw-r--r--kstars/kstars/thumbnailpicker.cpp6
-rw-r--r--kstars/kstars/timebox.cpp8
-rw-r--r--kstars/kstars/timezonerule.cpp8
-rw-r--r--kstars/kstars/timezonerule.h2
-rw-r--r--kstars/kstars/tools/altvstime.cpp4
-rw-r--r--kstars/kstars/tools/kstarsplotwidget.cpp16
-rw-r--r--kstars/kstars/tools/observinglist.cpp4
-rw-r--r--kstars/kstars/tools/observinglist.h2
-rw-r--r--kstars/kstars/tools/obslistwizard.cpp70
-rw-r--r--kstars/kstars/tools/scriptbuilder.cpp14
-rw-r--r--kstars/kstars/tools/scriptfunction.cpp4
52 files changed, 243 insertions, 243 deletions
diff --git a/kstars/README.i18n b/kstars/README.i18n
index 4ee54256..6953afba 100644
--- a/kstars/README.i18n
+++ b/kstars/README.i18n
@@ -48,7 +48,7 @@ this document to answer some questions you might have.
figure out the file format; briefly, it's a colon-delimited line
with fields: object name, link text, link URL
- Note that your alternate info_url.dat file will completely tqreplace
+ Note that your alternate info_url.dat file will completely replace
the default, so if you want to include some links from the original,
you will need to copy them over. Some of the sites we link to provide
versions of their pages in other languages (e.g., seds.org). So
diff --git a/kstars/kstars/colorscheme.cpp b/kstars/kstars/colorscheme.cpp
index 66981101..7c53a2e0 100644
--- a/kstars/kstars/colorscheme.cpp
+++ b/kstars/kstars/colorscheme.cpp
@@ -168,7 +168,7 @@ TQString ColorScheme::keyAt( int i ) const {
}
TQString ColorScheme::nameFromKey( const TQString &key ) const {
- return nameAt( KeyName.tqfindIndex( key ) );
+ return nameAt( KeyName.findIndex( key ) );
}
void ColorScheme::setColor( const TQString &key, const TQString &color ) {
@@ -191,8 +191,8 @@ bool ColorScheme::load( const TQString &filename ) {
bool ok(false);
int newmode = line.left(1).toInt( &ok );
if ( ok ) setStarColorMode( newmode );
- if ( line.tqcontains(':') ) {
- int newintens = line.mid( line.tqfind(':')+1, 2 ).toInt( &ok );
+ if ( line.contains(':') ) {
+ int newintens = line.mid( line.find(':')+1, 2 ).toInt( &ok );
if ( ok ) setStarColorIntensity( newintens );
}
@@ -201,19 +201,19 @@ bool ColorScheme::load( const TQString &filename ) {
while ( !stream.eof() ) {
line = stream.readLine();
- if ( line.tqcontains(':')==1 ) { //the new color preset format contains a ":" in each line, followed by the name of the color
+ if ( line.contains(':')==1 ) { //the new color preset format contains a ":" in each line, followed by the name of the color
++inew;
if ( iold ) return false; //we read at least one line without a colon...file is corrupted.
//If this line has a valid Key, set the color.
- TQString tkey = line.mid( line.tqfind(':')+1 ).stripWhiteSpace();
- TQString tname = line.left( line.tqfind(':')-1 );
+ TQString tkey = line.mid( line.find(':')+1 ).stripWhiteSpace();
+ TQString tname = line.left( line.find(':')-1 );
- if ( KeyName.tqcontains( tkey ) ) {
+ if ( KeyName.contains( tkey ) ) {
setColor( tkey, tname );
} else { //attempt to translate from old color ID
TQString k( line.mid( 5 ).stripWhiteSpace() + "Color" );
- if ( KeyName.tqcontains( k ) ) {
+ if ( KeyName.contains( k ) ) {
setColor( k, tname );
} else {
kdWarning() << "Could not use the key \"" << tkey <<
@@ -248,7 +248,7 @@ bool ColorScheme::save( const TQString &name ) {
TQString filename = name.lower().stripWhiteSpace();
if ( !filename.isEmpty() ) {
for( unsigned int i=0; i<filename.length(); ++i)
- if ( filename.at(i)==' ' ) filename.tqreplace( i, 1, "-" );
+ if ( filename.at(i)==' ' ) filename.replace( i, 1, "-" );
filename = filename.append( ".colors" );
file.setName( locateLocal( "appdata", filename ) ); //determine filename in local user KDE directory tree.
@@ -294,7 +294,7 @@ void ColorScheme::loadFromConfig( KConfig *conf ) {
TQStringList::Iterator it = KeyName.begin();
TQStringList::Iterator it_end = KeyName.end();
for ( ; it != it_end; ++it )
- setColor( TQString(*it), conf->readEntry( TQString(*it), TQString( *Default.at( KeyName.tqfindIndex(*it) ) ) ) );
+ setColor( TQString(*it), conf->readEntry( TQString(*it), TQString( *Default.at( KeyName.findIndex(*it) ) ) ) );
setStarColorMode( conf->readNumEntry( "StarColorMode", 0 ) );
setStarColorIntensity( conf->readNumEntry( "StarColorIntensity", 5 ) );
diff --git a/kstars/kstars/deepskyobject.cpp b/kstars/kstars/deepskyobject.cpp
index 5e0597f5..280729e5 100644
--- a/kstars/kstars/deepskyobject.cpp
+++ b/kstars/kstars/deepskyobject.cpp
@@ -88,7 +88,7 @@ void DeepSkyObject::setCatalog( const TQString &cat ) {
TQImage* DeepSkyObject::readImage( void ) {
TQFile file;
if ( Image==0 ) { //Image not currently set; try to load it from disk.
- TQString fname = name().lower().tqreplace( TQRegExp(" "), "" ) + ".png";
+ TQString fname = name().lower().replace( TQRegExp(" "), "" ) + ".png";
if ( KSUtils::openDataFile( file, fname ) ) {
file.close();
diff --git a/kstars/kstars/dms.cpp b/kstars/kstars/dms.cpp
index 587cca2c..3619a578 100644
--- a/kstars/kstars/dms.cpp
+++ b/kstars/kstars/dms.cpp
@@ -59,19 +59,19 @@ bool dms::setFromString( const TQString &str, bool isDeg ) {
//remove any instances of unit characters.
//h, d, m, s, ', ", or the degree symbol (ASCII 176)
- entry.tqreplace( TQRegExp("h"), "" );
- entry.tqreplace( TQRegExp("d"), "" );
- entry.tqreplace( TQRegExp("m"), "" );
- entry.tqreplace( TQRegExp("s"), "" );
+ entry.replace( TQRegExp("h"), "" );
+ entry.replace( TQRegExp("d"), "" );
+ entry.replace( TQRegExp("m"), "" );
+ entry.replace( TQRegExp("s"), "" );
TQString sdeg;
sdeg.sprintf("%c", 176);
- entry.tqreplace( TQRegExp(sdeg), "" );
- entry.tqreplace( TQRegExp("\'"), "" );
- entry.tqreplace( TQRegExp("\""), "" );
+ entry.replace( TQRegExp(sdeg), "" );
+ entry.replace( TQRegExp("\'"), "" );
+ entry.replace( TQRegExp("\""), "" );
//Account for localized decimal-point settings
//TQString::toDouble() requires that the decimal symbol is "."
- entry.tqreplace( KGlobal::locale()->decimalSymbol(), "." );
+ entry.replace( KGlobal::locale()->decimalSymbol(), "." );
//empty entry returns false
if ( entry.isEmpty() ) {
@@ -99,7 +99,7 @@ bool dms::setFromString( const TQString &str, bool isDeg ) {
TQStringList fields;
//check for colon-delimiters or space-delimiters
- if ( entry.tqcontains(':') )
+ if ( entry.contains(':') )
fields = TQStringList::split( ':', entry );
else fields = TQStringList::split( " ", entry );
diff --git a/kstars/kstars/draglistbox.cpp b/kstars/kstars/draglistbox.cpp
index bed2895b..a2b5a453 100644
--- a/kstars/kstars/draglistbox.cpp
+++ b/kstars/kstars/draglistbox.cpp
@@ -36,7 +36,7 @@ void DragListBox::dragEnterEvent( TQDragEnterEvent *evt )
evt->accept();
}
-bool DragListBox::tqcontains( const TQString &s ) const {
+bool DragListBox::contains( const TQString &s ) const {
for ( uint i=0; i<count(); ++i )
if ( text(i) == s ) return true;
diff --git a/kstars/kstars/draglistbox.h b/kstars/kstars/draglistbox.h
index c585c623..4ec1c987 100644
--- a/kstars/kstars/draglistbox.h
+++ b/kstars/kstars/draglistbox.h
@@ -43,7 +43,7 @@ public:
~DragListBox();
int ignoreIndex() const { return IgnoreIndex; }
- bool tqcontains( const TQString &s ) const;
+ bool contains( const TQString &s ) const;
void dragEnterEvent( TQDragEnterEvent *evt );
void dropEvent( TQDropEvent *evt );
diff --git a/kstars/kstars/filesource.cpp b/kstars/kstars/filesource.cpp
index 8a1854a4..8e38d9a4 100644
--- a/kstars/kstars/filesource.cpp
+++ b/kstars/kstars/filesource.cpp
@@ -27,7 +27,7 @@ FileSource::FileSource(KStarsData *ksdata, float magnitude)
// kdDebug() << "count()=" << data->starList.count() << endl;
fileNumber = ksdata->starList.count() / 1000 + 1;
lineNumber = ksdata->starList.count() % 1000;
- // the first file tqcontains 12 comment lines at the beginning which must skipped
+ // the first file contains 12 comment lines at the beginning which must skipped
if (fileNumber == 1) { lineNumber += 12; }
// kdDebug() << "fileNumber=" << fileNumber << " lineNumber=" << lineNumber << endl;
diff --git a/kstars/kstars/finddialog.h b/kstars/kstars/finddialog.h
index b3e559d4..83746c49 100644
--- a/kstars/kstars/finddialog.h
+++ b/kstars/kstars/finddialog.h
@@ -35,7 +35,7 @@ class TQListBoxItem;
class SkyObjectNameListItem;
/**@class FindDialog
- *Dialog window for finding SkyObjects by name. The dialog tqcontains
+ *Dialog window for finding SkyObjects by name. The dialog contains
*a TQListBox showing the list of named objects, a TQLineEdit for filtering
*the list by name, and a TQCombobox for filtering the list by object type.
*
diff --git a/kstars/kstars/fitsimage.cpp b/kstars/kstars/fitsimage.cpp
index 226cc74a..f12c890c 100644
--- a/kstars/kstars/fitsimage.cpp
+++ b/kstars/kstars/fitsimage.cpp
@@ -52,7 +52,7 @@
/* Load info */
typedef struct
{
- uint tqreplace; /* replacement for blank/NaN-values */
+ uint replace; /* replacement for blank/NaN-values */
uint use_datamin;/* Use DATAMIN/MAX-scaling if possible */
uint compose; /* compose images with naxis==3 */
} FITSLoadVals;
@@ -299,7 +299,7 @@ int FITSImage::loadFits (const char *filename)
}
trans.datamin = 0.0;
trans.datamax = 255.0;
- trans.replacement = plvals.tqreplace;
+ trans.replacement = plvals.replace;
trans.dsttyp = 'c';
//displayImage->create(width, height, 32);
diff --git a/kstars/kstars/fitsviewer.cpp b/kstars/kstars/fitsviewer.cpp
index ccf0f75d..32232235 100644
--- a/kstars/kstars/fitsviewer.cpp
+++ b/kstars/kstars/fitsviewer.cpp
@@ -549,7 +549,7 @@ void FITSViewer::fileSave()
currentURL = backupCurrent;
return;
}
- if (currentURL.path().tqcontains('.') == 0) currentURL.setPath(currentURL.path() + ".fits");
+ if (currentURL.path().contains('.') == 0) currentURL.setPath(currentURL.path() + ".fits");
if (TQFile::exists(currentURL.path()))
{
@@ -588,8 +588,8 @@ void FITSViewer::fileSave()
{
recordList = record[j];
- if ( (index = recordList.tqfind("BITPIX")) != -1)
- recordList.tqreplace(index, FITS_CARD_SIZE, bitpixRec);
+ if ( (index = recordList.find("BITPIX")) != -1)
+ recordList.replace(index, FITS_CARD_SIZE, bitpixRec);
fwrite(recordList.ascii(), 1, FITS_RECORD_SIZE, ifp->fp);
}
@@ -914,14 +914,14 @@ void FITSViewer::fitsHeader()
{
property = recordList.left(FITS_CARD_SIZE);
- equal = property.tqfind('=');
+ equal = property.find('=');
if (equal == -1)
{
- if (property.tqcontains(" ") != FITS_CARD_SIZE)
+ if (property.contains(" ") != FITS_CARD_SIZE)
cards << property << "" << "";
recordList.remove(0, FITS_CARD_SIZE);
- if (property.tqfind("END") != -1)
+ if (property.find("END") != -1)
break;
else
continue;
@@ -929,11 +929,11 @@ void FITSViewer::fitsHeader()
cards << property.left(equal);
- slash = property.tqfind("'");
+ slash = property.find("'");
if (slash != -1)
- slash = property.tqfind("'", slash + 1) + 1;
+ slash = property.find("'", slash + 1) + 1;
else
- slash = property.tqfind('/') - 1;
+ slash = property.find('/') - 1;
cards << property.mid(equal + 2, slash - (equal + 2)).simplifyWhiteSpace().remove("'");
cards << property.mid(slash + 1, FITS_CARD_SIZE - (slash + 1)).simplifyWhiteSpace();
diff --git a/kstars/kstars/fovdialog.cpp b/kstars/kstars/fovdialog.cpp
index 6cf848ac..88cdd3f4 100644
--- a/kstars/kstars/fovdialog.cpp
+++ b/kstars/kstars/fovdialog.cpp
@@ -171,7 +171,7 @@ void FOVDialog::slotEditFOV() {
FOV *newfov = new FOV( newfdlg.ui->FOVName->text(), newfdlg.ui->FOVEdit->text().toDouble(),
newfdlg.ui->ShapeBox->currentItem(), newfdlg.ui->ColorButton->color().name() );
fov->FOVListBox->changeItem( newfdlg.ui->FOVName->text(), fov->FOVListBox->currentItem() );
- FOVList.tqreplace( fov->FOVListBox->currentItem(), newfov );
+ FOVList.replace( fov->FOVListBox->currentItem(), newfov );
}
}
diff --git a/kstars/kstars/indi/LICENSE b/kstars/kstars/indi/LICENSE
index c4b38a7e..ae23fcfd 100644
--- a/kstars/kstars/indi/LICENSE
+++ b/kstars/kstars/indi/LICENSE
@@ -135,7 +135,7 @@ included without limitation in the term "modification".)
"Source code" for a work means the preferred form of the work for
making modifications to it. For a library, complete source code means
-all the source code for all modules it tqcontains, plus any associated
+all the source code for all modules it contains, plus any associated
interface definition files, plus the scripts used to control compilation
and installation of the library.
diff --git a/kstars/kstars/indi/fitsrw.c b/kstars/kstars/indi/fitsrw.c
index 69b934b2..b21622bf 100644
--- a/kstars/kstars/indi/fitsrw.c
+++ b/kstars/kstars/indi/fitsrw.c
@@ -1676,7 +1676,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{double offs, scale;
double datadiff, pixdiff;
unsigned char pixbuffer[4096], *pix, *cdata;
- unsigned char ctqreplace;
+ unsigned char creplace;
int transcount = 0;
long tdata, tmin, tmax;
int maxelem;
@@ -1706,7 +1706,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
if (tmax < 0) tmax = 0; else if (tmax > 255) tmax = 255;
cdata = (unsigned char *)buf;
- ctqreplace = (unsigned char)trans->replacement;
+ creplace = (unsigned char)trans->replacement;
switch (hdulist->bitpix)
{
@@ -1727,7 +1727,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
bp8 = (FITS_BITPIX8)*(pix++);
if (bp8 == bp8blank) /* Is it a blank pixel ? */
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else /* Do transform */
{
tdata = (long)(bp8 * scale + offs);
@@ -1770,7 +1770,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
FITS_GETBITPIX16 (pix, bp16);
if (bp16 == bp16blank)
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
tdata = (long)(bp16 * scale + offs);
@@ -1815,7 +1815,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
{
FITS_GETBITPIX32 (pix, bp32);
if (bp32 == bp32blank)
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
tdata = (long)(bp32 * scale + offs);
@@ -1856,7 +1856,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
while (maxelem--)
{
if (fits_nan_32 (pix)) /* An IEEE special value ? */
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else /* Do transform */
{
FITS_GETBITPIXM32 (pix, bpm32);
@@ -1884,7 +1884,7 @@ int fits_read_pixel (FITS_FILE *ff, FITS_HDU_LIST *hdulist, int npix,
while (maxelem--)
{
if (fits_nan_64 (pix))
- *(cdata++) = ctqreplace;
+ *(cdata++) = creplace;
else
{
FITS_GETBITPIXM64 (pix, bpm64);
diff --git a/kstars/kstars/indi/indiserver.c b/kstars/kstars/indi/indiserver.c
index 2f73ca5d..62a7c967 100644
--- a/kstars/kstars/indi/indiserver.c
+++ b/kstars/kstars/indi/indiserver.c
@@ -710,7 +710,7 @@ send2Clients (ClInfo *notme, XMLEle *root, char *dev)
pthread_mutex_unlock (&client_m);
}
-/* free Msg mp and everything it tqcontains */
+/* free Msg mp and everything it contains */
static void
freeMsg (Msg *mp)
{
diff --git a/kstars/kstars/indidriver.cpp b/kstars/kstars/indidriver.cpp
index 6ae5c5da..18337a1b 100644
--- a/kstars/kstars/indidriver.cpp
+++ b/kstars/kstars/indidriver.cpp
@@ -146,7 +146,7 @@ for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
{
if (devices[i]->mgrID == mgrID)
{
- affectedItem = localListView->tqfindItem(devices[i]->label, 0);
+ affectedItem = localListView->findItem(devices[i]->label, 0);
if (!affectedItem) return;
affectedItem->setPixmap(1, stopPix);
affectedItem->setPixmap(2, NULL);
@@ -640,19 +640,19 @@ bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
groupName = valuXMLAtt(ap);
- if (groupName.tqfind("Telescopes") != -1)
+ if (groupName.find("Telescopes") != -1)
groupType = KSTARS_TELESCOPE;
- else if (groupName.tqfind("CCDs") != -1)
+ else if (groupName.find("CCDs") != -1)
groupType = KSTARS_CCD;
- else if (groupName.tqfind("Filter") != -1)
+ else if (groupName.find("Filter") != -1)
groupType = KSTARS_FILTER;
- else if (groupName.tqfind("Video") != -1)
+ else if (groupName.find("Video") != -1)
groupType = KSTARS_VIDEO;
- else if (groupName.tqfind("Focusers") != -1)
+ else if (groupName.find("Focusers") != -1)
groupType = KSTARS_FOCUSER;
- else if (groupName.tqfind("Domes") != -1)
+ else if (groupName.find("Domes") != -1)
groupType = KSTARS_DOME;
- else if (groupName.tqfind("GPS") != -1)
+ else if (groupName.find("GPS") != -1)
groupType = KSTARS_GPS;
@@ -829,7 +829,7 @@ void INDIDriver::modifyINDIHost()
currentItem->setText(1, hostConf.nameIN->text());
currentItem->setText(2, hostConf.portnumber->text());
- ksw->data()->INDIHostsList.tqreplace(clientListView->itemIndex(currentItem), hostItem);
+ ksw->data()->INDIHostsList.replace(clientListView->itemIndex(currentItem), hostItem);
saveHosts();
}
diff --git a/kstars/kstars/indielement.cpp b/kstars/kstars/indielement.cpp
index 248007af..ed1834c0 100644
--- a/kstars/kstars/indielement.cpp
+++ b/kstars/kstars/indielement.cpp
@@ -37,7 +37,7 @@
#include <kdialogbase.h>
/* search element for attribute.
- * return XMLAtt if tqfind, else NULL with helpful info in errmsg.
+ * return XMLAtt if find, else NULL with helpful info in errmsg.
*/
XMLAtt * findAtt (XMLEle *ep, const char *name, char errmsg[])
{
@@ -50,7 +50,7 @@ XMLAtt * findAtt (XMLEle *ep, const char *name, char errmsg[])
}
/* search element for given child. pp is just to build a better errmsg.
- * return XMLEle if tqfind, else NULL with helpful info in errmsg.
+ * return XMLEle if find, else NULL with helpful info in errmsg.
*/
XMLEle * findEle (XMLEle *ep, INDI_P *pp, const char *child, char errmsg[])
{
diff --git a/kstars/kstars/indimenu.cpp b/kstars/kstars/indimenu.cpp
index a3b0be1e..354e8a9e 100644
--- a/kstars/kstars/indimenu.cpp
+++ b/kstars/kstars/indimenu.cpp
@@ -222,7 +222,7 @@ void INDIMenu::setCustomLabel(TQString deviceName)
for (unsigned int i=0; i < mgr.count(); i++)
for (unsigned int j=0; j < mgr.at(i)->indi_dev.count(); j++)
- if (mgr.at(i)->indi_dev.at(j)->label.tqfind(deviceName) >= 0)
+ if (mgr.at(i)->indi_dev.at(j)->label.find(deviceName) >= 0)
nset++;
if (nset)
diff --git a/kstars/kstars/indiproperty.cpp b/kstars/kstars/indiproperty.cpp
index dbdbca94..0da730ee 100644
--- a/kstars/kstars/indiproperty.cpp
+++ b/kstars/kstars/indiproperty.cpp
@@ -209,18 +209,18 @@ void INDI_P::convertSwitch(int id)
if (assosiatedPopup == NULL)
return;
- mLabel = assosiatedPopup->text(id).tqreplace("&", "");
+ mLabel = assosiatedPopup->text(id).replace("&", "");
//kdDebug() << "Name: " << name << " ID: " << id << endl;
/* Special case is CCD_EXPOSE_DURATION, not a switch */
- if (stdID == CCD_EXPOSE_DURATION && mLabel.tqfind(label) != -1)
+ if (stdID == CCD_EXPOSE_DURATION && mLabel.find(label) != -1)
{
newText();
return;
}
/* Another special case, center telescope */
- if (mLabel.tqfind("Crosshair") != -1)
+ if (mLabel.find("Crosshair") != -1)
{
if (!indistd->stdDev->dp->isOn()) return;
if (indistd->stdDev->telescopeSkyObject == NULL) return;
@@ -339,7 +339,7 @@ void INDI_P::newBlob()
fp.setName(filename);
- if ( (pos = filename.tqfindRev(".")) != -1)
+ if ( (pos = filename.findRev(".")) != -1)
format = filename.mid (pos, filename.length());
if (!fp.open(IO_ReadOnly))
diff --git a/kstars/kstars/indistd.cpp b/kstars/kstars/indistd.cpp
index ff9f1ad8..93610907 100644
--- a/kstars/kstars/indistd.cpp
+++ b/kstars/kstars/indistd.cpp
@@ -472,7 +472,7 @@ void INDIStdDevice::handleBLOB(unsigned char *buffer, int bufferSize, TQString d
tempName = it.current()->name();
// find the prefix first
- if (tempName.tqfind(seqPrefix) == -1)
+ if (tempName.find(seqPrefix) == -1)
continue;
strncpy(tempPrefix, tempName.ascii(), 64);
diff --git a/kstars/kstars/infoboxes.cpp b/kstars/kstars/infoboxes.cpp
index fdd95517..dff865e4 100644
--- a/kstars/kstars/infoboxes.cpp
+++ b/kstars/kstars/infoboxes.cpp
@@ -126,17 +126,17 @@ void InfoBoxes::drawBoxes( TQPainter &p, TQColor FGColor, TQColor grabColor,
}
bool InfoBoxes::grabBox( TQMouseEvent *e ) {
- if ( GeoBox->rect().tqcontains( e->pos() ) ) {
+ if ( GeoBox->rect().contains( e->pos() ) ) {
GrabbedBox = 1;
GrabPos.setX( e->x() - GeoBox->x() );
GrabPos.setY( e->y() - GeoBox->y() );
return true;
- } else if ( TimeBox->rect().tqcontains( e->pos() ) ) {
+ } else if ( TimeBox->rect().contains( e->pos() ) ) {
GrabbedBox = 2;
GrabPos.setX( e->x() - TimeBox->x() );
GrabPos.setY( e->y() - TimeBox->y() );
return true;
- } else if ( FocusBox->rect().tqcontains( e->pos() ) ) {
+ } else if ( FocusBox->rect().contains( e->pos() ) ) {
GrabbedBox = 3;
GrabPos.setX( e->x() - FocusBox->x() );
GrabPos.setY( e->y() - FocusBox->y() );
@@ -180,7 +180,7 @@ bool InfoBoxes::dragBox( TQMouseEvent *e ) {
}
bool InfoBoxes::shadeBox( TQMouseEvent *e ) {
- if ( GeoBox->rect().tqcontains( e->pos() ) ) {
+ if ( GeoBox->rect().contains( e->pos() ) ) {
GeoBox->toggleShade();
if ( GeoBox->rect().bottom() > height() ) GeoBox->move( GeoBox->x(), height() - GeoBox->height() );
if ( GeoBox->rect().right() > width() ) GeoBox->move( width() - GeoBox->width(), GeoBox->y() );
@@ -189,7 +189,7 @@ bool InfoBoxes::shadeBox( TQMouseEvent *e ) {
fixCollisions( TimeBox );
fixCollisions( FocusBox );
return true;
- } else if ( TimeBox->rect().tqcontains( e->pos() ) ) {
+ } else if ( TimeBox->rect().contains( e->pos() ) ) {
TimeBox->toggleShade();
if ( TimeBox->rect().bottom() > height() ) TimeBox->move( TimeBox->x(), height() - TimeBox->height() );
if ( TimeBox->rect().right() > width() ) TimeBox->move( width() - TimeBox->width(), TimeBox->y() );
@@ -198,7 +198,7 @@ bool InfoBoxes::shadeBox( TQMouseEvent *e ) {
fixCollisions( GeoBox );
fixCollisions( FocusBox );
return true;
- } else if ( FocusBox->rect().tqcontains( e->pos() ) ) {
+ } else if ( FocusBox->rect().contains( e->pos() ) ) {
FocusBox->toggleShade();
if ( FocusBox->rect().bottom() > height() ) FocusBox->move( FocusBox->x(), height() - FocusBox->height() );
if ( FocusBox->rect().right() > width() ) FocusBox->move( width() - FocusBox->width(), FocusBox->y() );
@@ -248,7 +248,7 @@ bool InfoBoxes::fixCollisions( InfoBox *target ) {
if ( Box2.width() ) Box2.setCoords( Box2.left()+1, Box2.top()+1, Box2.right()-1, Box2.bottom()-1 );
//First, make sure target box is within area rect.
- if ( ! area.tqcontains( t ) ) {
+ if ( ! area.contains( t ) ) {
/* if ( t.x() < area.x() ) target->move( area.x(), t.y() );
if ( t.y() < area.y() ) target->move( t.x(), area.y() );
if ( t.right() > area.right() ){ target->move( area.right() - t.width(), t.y() ); }
@@ -280,25 +280,25 @@ bool InfoBoxes::fixCollisions( InfoBox *target ) {
leftRect.moveTopLeft( TQPoint( t.x() - dLeft, t.y() ) );
}
//If leftRect is outside area, set dLeft to a nonsense large value
- if ( !area.tqcontains( leftRect ) ) { dLeft = 100000; }
+ if ( !area.contains( leftRect ) ) { dLeft = 100000; }
//repeat for right, up and down directions.
while ( rightRect.intersects( Box1 ) || rightRect.intersects( Box2 ) ) {
++dRight;
rightRect.moveTopLeft( TQPoint( t.x() + dRight, t.y() ) );
}
- if ( !area.tqcontains( rightRect ) ) { dRight = 100000; }
+ if ( !area.contains( rightRect ) ) { dRight = 100000; }
while ( upRect.intersects( Box1 ) || upRect.intersects( Box2 ) ) {
++dUp;
upRect.moveTopLeft( TQPoint( t.x(), t.y() - dUp ) );
}
- if ( !area.tqcontains( upRect ) ) { dUp = 100000; }
+ if ( !area.contains( upRect ) ) { dUp = 100000; }
while ( downRect.intersects( Box1 ) || downRect.intersects( Box2 ) ) {
++dDown;
downRect.moveTopLeft( TQPoint( t.x(), t.y() + dDown ) );
}
- if ( !area.tqcontains( downRect ) ) { dDown = 100000; }
+ if ( !area.contains( downRect ) ) { dDown = 100000; }
//find the smallest displacement, and move the target box there.
@@ -331,7 +331,7 @@ bool InfoBoxes::fixCollisions( InfoBox *target ) {
//Final check to see if we're still inside area (we may not be if target
//is bigger than area)
- if ( area.tqcontains( target->rect() ) ) return true;
+ if ( area.contains( target->rect() ) ) return true;
else return false;
}
@@ -351,7 +351,7 @@ bool InfoBoxes::timeChanged( const KStarsDateTime &ut, const KStarsDateTime &lt,
//Don't use KLocale::formatNumber() for Julian Day because we don't want
//thousands-place separators
TQString JDString = TQString::number( ut.djd(), 'f', 2 );
- JDString.tqreplace( ".", KGlobal::locale()->decimalSymbol() );
+ JDString.replace( ".", KGlobal::locale()->decimalSymbol() );
TimeBox->setText3( i18n( "Sidereal Time", "ST: " ) + STString +
i18n( "Julian Day", "JD: " ) + JDString );
diff --git a/kstars/kstars/kscomet.cpp b/kstars/kstars/kscomet.cpp
index e36463d2..94ed1762 100644
--- a/kstars/kstars/kscomet.cpp
+++ b/kstars/kstars/kscomet.cpp
@@ -49,9 +49,9 @@ KSComet::KSComet( KStarsData *_kd, TQString _s, TQString imfile,
P = 365.2568984 * pow(a, 1.5); //period in days
//If the name contains a "/", make this name2 and make name a truncated version without the leading "P/" or "C/"
- if ( name().tqcontains( "/" ) ) {
+ if ( name().contains( "/" ) ) {
setLongName( name() );
- setName( name().mid( name().tqfind("/") + 1 ) );
+ setName( name().mid( name().find("/") + 1 ) );
}
}
diff --git a/kstars/kstars/ksnewstuff.cpp b/kstars/kstars/ksnewstuff.cpp
index aec4185e..4b0ed9e8 100644
--- a/kstars/kstars/ksnewstuff.cpp
+++ b/kstars/kstars/ksnewstuff.cpp
@@ -79,7 +79,7 @@ void KSNewStuff::updateData( const TQString &path ) {
//Handle the Steinicke NGC/IC catalog
- if ( !NGCUpdated && qd[0].tqcontains( "ngcic" ) ) {
+ if ( !NGCUpdated && qd[0].contains( "ngcic" ) ) {
//Build a progress dialog to show during data installation.
KProgressDialog prog( 0, "newstuffprogdialog",
i18n( "Please Wait" ), i18n( "Installing Steinicke NGC/IC catalog..." ), false /*modal*/ );
diff --git a/kstars/kstars/kspopupmenu.cpp b/kstars/kstars/kspopupmenu.cpp
index 97fd16f5..907371ef 100644
--- a/kstars/kstars/kspopupmenu.cpp
+++ b/kstars/kstars/kspopupmenu.cpp
@@ -320,7 +320,7 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, TQString s1, TQString s2, TQStr
}
if ( showObsList && obj ) {
- if ( ksw->observingList()->tqcontains( obj ) )
+ if ( ksw->observingList()->contains( obj ) )
insertItem( i18n("Remove From List"), ksw->observingList(), TQT_SLOT( slotRemoveObject() ) );
else
insertItem( i18n("Add to List"), ksw->observingList(), TQT_SLOT( slotAddObject() ) );
diff --git a/kstars/kstars/kstarsactions.cpp b/kstars/kstars/kstarsactions.cpp
index 67807992..802d8ab8 100644
--- a/kstars/kstars/kstarsactions.cpp
+++ b/kstars/kstars/kstarsactions.cpp
@@ -535,7 +535,7 @@ void KStars::slotRunScript() {
// Before we run the script, make sure that it's safe. Each line must either begin with "#"
// or begin with "dcop $KSTARS". Otherwise, the line must be equal to one of the following:
- // "KSTARS=`dcoptqfind -a 'kstars*'`"; "MAIN=KStarsInterface"; or "CLOCK=clock#1"
+ // "KSTARS=`dcopfind -a 'kstars*'`"; "MAIN=KStarsInterface"; or "CLOCK=clock#1"
TQTextStream istream(&f);
TQString line;
bool fileOK( true );
@@ -543,7 +543,7 @@ void KStars::slotRunScript() {
while ( ! istream.eof() ) {
line = istream.readLine();
if ( line.left(1) != "#" && line.left(12) != "dcop $KSTARS"
- && line.stripWhiteSpace() != "KSTARS=`dcoptqfind -a 'kstars*'`"
+ && line.stripWhiteSpace() != "KSTARS=`dcopfind -a 'kstars*'`"
&& line.stripWhiteSpace() != "MAIN=KStarsInterface"
&& line.stripWhiteSpace() != "CLOCK=clock#1" ) {
fileOK = false;
diff --git a/kstars/kstars/kstarsdata.h b/kstars/kstars/kstarsdata.h
index 0ba7b40b..ec84d391 100644
--- a/kstars/kstars/kstarsdata.h
+++ b/kstars/kstars/kstarsdata.h
@@ -135,7 +135,7 @@ public:
*/
bool readTimeZoneRulebook( void );
- /**Parse one line from a locations database file. The line tqcontains 10 or 11 fields
+ /**Parse one line from a locations database file. The line contains 10 or 11 fields
*separated by colons (":"). The fields are:
*@li City Name [string]
*@li Province Name (optional) [string]
@@ -352,7 +352,7 @@ public:
/**Read in URLs to be attached to a named object's right-click popup menu. At this
*point, there is no way to attach URLs to unnamed objects. There are two
*kinds of URLs, each with its own data file: image links and webpage links. In addition,
- *there may be user-specific versions with custom URLs. Each line tqcontains 3 fields
+ *there may be user-specific versions with custom URLs. Each line contains 3 fields
*separated by colons (":"). Note that the last field is the URL, and as such it will
*generally contain a colon itself. Only the first two colons encountered are treated
*as field separators. The fields are:
@@ -450,7 +450,7 @@ public:
KSPlanet *earth() { return PCat->earth(); }
/**@short Find object by name.
- *@param name Object name to tqfind
+ *@param name Object name to find
*@return pointer to SkyObject matching this name
*/
SkyObject* objectNamed( const TQString &name );
diff --git a/kstars/kstars/kstarsdcop.cpp b/kstars/kstars/kstarsdcop.cpp
index 8a5ce618..8649ccba 100644
--- a/kstars/kstars/kstarsdcop.cpp
+++ b/kstars/kstars/kstarsdcop.cpp
@@ -359,7 +359,7 @@ void KStars::loadColorScheme( const TQString _name ) {
if ( ! ok ) {
if ( !filename.isEmpty() ) {
for( unsigned int i=0; i<filename.length(); ++i)
- if ( filename.at(i)==' ' ) filename.tqreplace( i, 1, "-" );
+ if ( filename.at(i)==' ' ) filename.replace( i, 1, "-" );
filename = filename.append( ".colors" );
ok = data()->colorScheme()->load( filename );
@@ -392,7 +392,7 @@ void KStars::exportImage( const TQString url, int w, int h ) {
//If the filename string contains no "/" separators, assume the
//user wanted to place a file in their home directory.
KURL fileURL;
- if ( ! url.tqcontains( "/" ) ) fileURL = TQDir::homeDirPath() + "/" + url;
+ if ( ! url.contains( "/" ) ) fileURL = TQDir::homeDirPath() + "/" + url;
else fileURL = url;
KTempFile tmpfile;
@@ -411,7 +411,7 @@ void KStars::exportImage( const TQString url, int w, int h ) {
}
//Determine desired image format from filename extension
- TQString ext = fname.mid( fname.tqfindRev(".")+1 );
+ TQString ext = fname.mid( fname.findRev(".")+1 );
const char* format = "PNG";
if ( ext.lower() == "png" ) { format = "PNG"; }
else if ( ext.lower() == "jpg" || ext.lower() == "jpeg" ) { format = "JPG"; }
@@ -512,7 +512,7 @@ void KStars::startINDI (TQString deviceName, bool useLocal)
}
TQListViewItem *driverItem = NULL;
- driverItem = indidriver->localListView->tqfindItem(deviceName, 0);
+ driverItem = indidriver->localListView->findItem(deviceName, 0);
if (driverItem == NULL)
{
kdDebug() << "Device " << deviceName << " not found!" << endl;
@@ -551,7 +551,7 @@ void KStars::shutdownINDI (TQString deviceName)
}
TQListViewItem *driverItem = NULL;
- driverItem = indidriver->localListView->tqfindItem(deviceName, 0);
+ driverItem = indidriver->localListView->findItem(deviceName, 0);
if (driverItem == NULL)
{
kdDebug() << "Device " << deviceName << " not found!" << endl;
diff --git a/kstars/kstars/kstarsinit.cpp b/kstars/kstars/kstarsinit.cpp
index 544d9d9d..57a7e076 100644
--- a/kstars/kstars/kstarsinit.cpp
+++ b/kstars/kstars/kstarsinit.cpp
@@ -178,9 +178,9 @@ void KStars::initActions() {
while ( !stream.eof() ) {
line = stream.readLine();
- schemeName = line.left( line.tqfind( ':' ) );
+ schemeName = line.left( line.find( ':' ) );
//I call it filename here, but it's used as the name of the action!
- filename = "cs_" + line.mid( line.tqfind( ':' ) +1, line.tqfind( '.' ) - line.tqfind( ':' ) - 1 );
+ filename = "cs_" + line.mid( line.find( ':' ) +1, line.find( '.' ) - line.find( ':' ) - 1 );
addColorMenuItem( i18n( schemeName.local8Bit() ), filename.local8Bit() );
}
file.close();
diff --git a/kstars/kstars/locationdialog.cpp b/kstars/kstars/locationdialog.cpp
index b00d5ba0..ec5e28a2 100644
--- a/kstars/kstars/locationdialog.cpp
+++ b/kstars/kstars/locationdialog.cpp
@@ -224,7 +224,7 @@ void LocationDialog::initCityList( void ) {
filteredCityList.append( loc );
//If TZ is not even integer value, add it to listbox
- if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->tqfindItem( KGlobal::locale()->formatNumber( loc->TZ0() ) ) ) {
+ if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->findItem( KGlobal::locale()->formatNumber( loc->TZ0() ) ) ) {
for ( unsigned int i=0; i<((unsigned int) TZBox->count()); ++i ) {
if ( TZBox->text( i ).toDouble() > loc->TZ0() ) {
TZBox->insertItem( KGlobal::locale()->formatNumber( loc->TZ0() ), i-1 );
diff --git a/kstars/kstars/main.cpp b/kstars/kstars/main.cpp
index c79fc0ad..b96756c4 100644
--- a/kstars/kstars/main.cpp
+++ b/kstars/kstars/main.cpp
@@ -73,7 +73,7 @@ int main(int argc, char *argv[])
//parse filename and image format
const char* format = "PNG";
TQString fname = args->getOption( "filename" );
- TQString ext = fname.mid( fname.tqfindRev(".")+1 );
+ TQString ext = fname.mid( fname.findRev(".")+1 );
if ( ext.lower() == "png" ) { format = "PNG"; }
else if ( ext.lower() == "jpg" || ext.lower() == "jpeg" ) { format = "JPG"; }
else if ( ext.lower() == "gif" ) { format = "GIF"; }
@@ -109,8 +109,8 @@ int main(int argc, char *argv[])
TQString datestring = args->getOption( "date" );
KStarsDateTime kdt;
if ( ! datestring.isEmpty() ) {
- if ( datestring.tqcontains( "-" ) ) { //assume ISODate format
- if ( datestring.tqcontains( ":" ) ) { //also includes time
+ if ( datestring.contains( "-" ) ) { //assume ISODate format
+ if ( datestring.contains( ":" ) ) { //also includes time
kdt = KStarsDateTime::fromString( datestring, Qt::ISODate );
} else { //string probably contains date only
kdt.setDate( ExtDate::fromString( datestring, Qt::ISODate ) );
diff --git a/kstars/kstars/objectnamelist.cpp b/kstars/kstars/objectnamelist.cpp
index 8a35ea0a..b86fdac8 100644
--- a/kstars/kstars/objectnamelist.cpp
+++ b/kstars/kstars/objectnamelist.cpp
@@ -184,11 +184,11 @@ void ObjectNameList::remove ( const TQString &name ) {
int index = getIndex(name);
SortedList <SkyObjectName> *l = &(list[language][index]);
- SkyObjectName *son = tqfind( name );
+ SkyObjectName *son = find( name );
if ( son ) l->remove( son );
}
-SkyObjectName* ObjectNameList::tqfind(const TQString &name) {
+SkyObjectName* ObjectNameList::find(const TQString &name) {
sort();
if (name.isNull()) return 0;
// find works only in one list and not in all lists
diff --git a/kstars/kstars/opscatalog.cpp b/kstars/kstars/opscatalog.cpp
index c3701446..764113a4 100644
--- a/kstars/kstars/opscatalog.cpp
+++ b/kstars/kstars/opscatalog.cpp
@@ -90,7 +90,7 @@ void OpsCatalog::updateDisplay() {
Options::setShowNGC( showNGC->isOn() );
Options::setShowIC( showIC->isOn() );
for ( unsigned int i=0; i<ksw->data()->customCatalogs().count(); ++i ) {
- TQCheckListItem *item = (TQCheckListItem*)( CatalogList->tqfindItem( ksw->data()->customCatalogs().at(i)->name(), 0 ));
+ TQCheckListItem *item = (TQCheckListItem*)( CatalogList->findItem( ksw->data()->customCatalogs().at(i)->name(), 0 ));
Options::showCatalog()[i] = item->isOn();
}
diff --git a/kstars/kstars/opscolors.cpp b/kstars/kstars/opscolors.cpp
index 73f6ca59..66358f25 100644
--- a/kstars/kstars/opscolors.cpp
+++ b/kstars/kstars/opscolors.cpp
@@ -62,8 +62,8 @@ OpsColors::OpsColors( TQWidget *p, const char *name, WFlags fl )
while ( !stream.eof() ) {
line = stream.readLine();
- schemeName = line.left( line.tqfind( ':' ) );
- filename = line.mid( line.tqfind( ':' ) +1, line.length() );
+ schemeName = line.left( line.find( ':' ) );
+ filename = line.mid( line.find( ':' ) +1, line.length() );
PresetBox->insertItem( schemeName );
PresetFileList.append( filename );
}
@@ -166,10 +166,10 @@ void OpsColors::slotAddPreset() {
if ( okPressed && ! schemename.isEmpty() ) {
if ( ksw->data()->colorScheme()->save( schemename ) ) {
PresetBox->insertItem( schemename );
- PresetBox->setCurrentItem( PresetBox->tqfindItem( schemename ) );
+ PresetBox->setCurrentItem( PresetBox->findItem( schemename ) );
TQString fname = ksw->data()->colorScheme()->fileName();
PresetFileList.append( fname );
- ksw->addColorMenuItem( schemename, TQString("cs_" + fname.left(fname.tqfind(".colors"))).utf8() );
+ ksw->addColorMenuItem( schemename, TQString("cs_" + fname.left(fname.find(".colors"))).utf8() );
}
}
}
@@ -181,7 +181,7 @@ void OpsColors::slotRemovePreset() {
cdatFile.setName( locateLocal( "appdata", "colors.dat" ) ); //determine filename in local user KDE directory tree.
//Remove action from color-schemes menu
- ksw->removeColorMenuItem( TQString("cs_" + filename.left( filename.tqfind(".colors"))).utf8() );
+ ksw->removeColorMenuItem( TQString("cs_" + filename.left( filename.find(".colors"))).utf8() );
if ( !cdatFile.exists() || !cdatFile.open( IO_ReadWrite ) ) {
TQString message = i18n( "Local color scheme index file could not be opened.\nScheme cannot be removed." );
@@ -205,7 +205,7 @@ void OpsColors::slotRemovePreset() {
while ( !stream.eof() ) {
TQString line = stream.readLine();
- if ( line.left( line.tqfind(':') ) != name ) slist.append( line );
+ if ( line.left( line.find(':') ) != name ) slist.append( line );
else removed = true;
}
diff --git a/kstars/kstars/skymapdraw.cpp b/kstars/kstars/skymapdraw.cpp
index 7d06c5fb..77f17268 100644
--- a/kstars/kstars/skymapdraw.cpp
+++ b/kstars/kstars/skymapdraw.cpp
@@ -1578,7 +1578,7 @@ void SkyMap::drawPlanetTrail( TQPainter& psky, KSPlanetBase *ksp, double scale )
if ( ( o.x() >= -1000 && o.x() <= Width+1000 && o.y() >=-1000 && o.y() <= Height+1000 ) ) {
//Want to disable line-drawing if this point and the last are both outside bounds of display.
- if ( ! TQT_TQRECT_OBJECT(rect()).tqcontains( o ) && ! TQT_TQRECT_OBJECT(rect()).tqcontains( cur ) ) doDrawLine = false;
+ if ( ! TQT_TQRECT_OBJECT(rect()).contains( o ) && ! TQT_TQRECT_OBJECT(rect()).contains( cur ) ) doDrawLine = false;
cur = o;
if ( doDrawLine ) {
diff --git a/kstars/kstars/skypoint.cpp b/kstars/kstars/skypoint.cpp
index eadfe6c5..ea3f7093 100644
--- a/kstars/kstars/skypoint.cpp
+++ b/kstars/kstars/skypoint.cpp
@@ -770,7 +770,7 @@ TQString SkyPoint::constellation( TQPtrList<CSegment> &csegmentList, TQPtrList<S
if ( abbrev.lower() == o->name2().lower() ) {
TQString r = i18n( "Constellation name (optional)", o->name().local8Bit().data() );
r = r.left(1) + r.mid(1).lower(); //lowercase letters (except first letter)
- int i = r.tqfind(" ");
+ int i = r.find(" ");
i++;
if ( i>0 ) r = r.left(i) + r.mid(i,1).upper() + r.mid(i+1); //capitalize 2nd word
return r;
diff --git a/kstars/kstars/telescopewizardprocess.cpp b/kstars/kstars/telescopewizardprocess.cpp
index 4538ba14..b2be4995 100644
--- a/kstars/kstars/telescopewizardprocess.cpp
+++ b/kstars/kstars/telescopewizardprocess.cpp
@@ -230,7 +230,7 @@ int telescopeWizardProcess::establishLink()
return (0);
TQListViewItem *driverItem = NULL;
- driverItem = indidriver->localListView->tqfindItem(telescopeCombo->currentText(), 0);
+ driverItem = indidriver->localListView->findItem(telescopeCombo->currentText(), 0);
if (driverItem == NULL) return -1;
// If device is already running, we need to shut it down first
diff --git a/kstars/kstars/thumbnaileditor.cpp b/kstars/kstars/thumbnaileditor.cpp
index a8822439..53235044 100644
--- a/kstars/kstars/thumbnaileditor.cpp
+++ b/kstars/kstars/thumbnaileditor.cpp
@@ -130,7 +130,7 @@ void ThumbImage::paintEvent( TQPaintEvent* ) {
}
void ThumbImage::mousePressEvent( TQMouseEvent *e ) {
- if ( e->button() == Qt::LeftButton && CropRect->tqcontains( e->pos() ) ) {
+ if ( e->button() == Qt::LeftButton && CropRect->contains( e->pos() ) ) {
bMouseButtonDown = true;
//The Anchor tells how far from the CropRect corner we clicked
diff --git a/kstars/kstars/thumbnailpicker.cpp b/kstars/kstars/thumbnailpicker.cpp
index e8544b6b..0d7d0265 100644
--- a/kstars/kstars/thumbnailpicker.cpp
+++ b/kstars/kstars/thumbnailpicker.cpp
@@ -141,14 +141,14 @@ void ThumbnailPicker::parseGooglePage( TQStringList &ImList, TQString URL ) {
return;
}
- int index = PageHTML.tqfind( "?imgurl=", 0 );
+ int index = PageHTML.find( "?imgurl=", 0 );
while ( index >= 0 ) {
index += 8; //move to end of "?imgurl=" marker
//Image URL is everything from index to next occurence of "&"
- ImList.append( PageHTML.mid( index, PageHTML.tqfind( "&", index ) - index ) );
+ ImList.append( PageHTML.mid( index, PageHTML.find( "&", index ) - index ) );
- index = PageHTML.tqfind( "?imgurl=", index );
+ index = PageHTML.find( "?imgurl=", index );
}
}
diff --git a/kstars/kstars/timebox.cpp b/kstars/kstars/timebox.cpp
index 5f6040f0..c97b4a89 100644
--- a/kstars/kstars/timebox.cpp
+++ b/kstars/kstars/timebox.cpp
@@ -91,7 +91,7 @@ TQTime timeBox::createTime ( bool *ok )
TQStringList fields;
//check for colon-delimiters or space-delimiters
- if ( entry.tqcontains(':') )
+ if ( entry.contains(':') )
fields = TQStringList::split( ':', entry );
else fields = TQStringList::split( " ", entry );
@@ -113,9 +113,9 @@ TQTime timeBox::createTime ( bool *ok )
// ignore all after 3rd field
if ( fields.count() >= 3 ) {
- fields[0].tqreplace( TQRegExp("h"), "" );
- fields[1].tqreplace( TQRegExp("m"), "" );
- fields[2].tqreplace( TQRegExp("s"), "" );
+ fields[0].replace( TQRegExp("h"), "" );
+ fields[1].replace( TQRegExp("m"), "" );
+ fields[2].replace( TQRegExp("s"), "" );
}
//See if first two fields parse as integers.
//
diff --git a/kstars/kstars/timezonerule.cpp b/kstars/kstars/timezonerule.cpp
index 1d66d32c..0a711f57 100644
--- a/kstars/kstars/timezonerule.cpp
+++ b/kstars/kstars/timezonerule.cpp
@@ -168,7 +168,7 @@ int TimeZoneRule::findStartDay( const KStarsDateTime &d ) {
return test.day();
}
-int TimeZoneRule::tqfindRevertDay( const KStarsDateTime &d ) {
+int TimeZoneRule::findRevertDay( const KStarsDateTime &d ) {
// Determine the calendar date of RevertDay for the month and year of the given date.
ExtDate test;
@@ -215,7 +215,7 @@ bool TimeZoneRule::isDSTActive( const KStarsDateTime &date ) {
if ( day < sday ) return false;
if ( day==sday && date.time() < StartTime ) return false;
} else if ( month == RevertMonth ) {
- int rday = tqfindRevertDay( date );
+ int rday = findRevertDay( date );
if ( day > rday ) return false;
if ( day==rday && date.time() > RevertTime ) return false;
}
@@ -239,7 +239,7 @@ void TimeZoneRule::nextDSTChange_LTime( const KStarsDateTime &date ) {
if ( RevertMonth < date.date().month() ) ++y;
result = KStarsDateTime( ExtDate( y, RevertMonth, 1 ), RevertTime );
- result = KStarsDateTime( ExtDate( y, RevertMonth, tqfindRevertDay( result ) ), RevertTime );
+ result = KStarsDateTime( ExtDate( y, RevertMonth, findRevertDay( result ) ), RevertTime );
} else {
// Next change is starting DST.
@@ -284,7 +284,7 @@ void TimeZoneRule::previousDSTChange_LTime( const KStarsDateTime &date ) {
if ( RevertMonth > date.date().month() ) --y;
result = KStarsDateTime( ExtDate( y, RevertMonth, 1 ), RevertTime );
- result = KStarsDateTime( ExtDate( y, RevertMonth, tqfindRevertDay( result ) ), RevertTime );
+ result = KStarsDateTime( ExtDate( y, RevertMonth, findRevertDay( result ) ), RevertTime );
}
kdDebug() << i18n( "Previous Daylight Savings Time change (Local Time): " ) << result.toString() << endl;
diff --git a/kstars/kstars/timezonerule.h b/kstars/kstars/timezonerule.h
index 53ade37e..3cadb4e5 100644
--- a/kstars/kstars/timezonerule.h
+++ b/kstars/kstars/timezonerule.h
@@ -158,7 +158,7 @@ private:
*of the given KStarsDateTime.
*@p d the date containing the year to be tested
*@return the calendar date, an integer between 1 and 31. */
- int tqfindRevertDay( const KStarsDateTime &d );
+ int findRevertDay( const KStarsDateTime &d );
int StartDay, RevertDay;
int StartWeek, RevertWeek;
diff --git a/kstars/kstars/tools/altvstime.cpp b/kstars/kstars/tools/altvstime.cpp
index 4c51a6a4..27f94fc4 100644
--- a/kstars/kstars/tools/altvstime.cpp
+++ b/kstars/kstars/tools/altvstime.cpp
@@ -400,7 +400,7 @@ void AltVsTime::slotUpdateDateLoc(void) {
o->updateCoords( num );
//update pList entry
- pList.tqreplace( i, (SkyPoint*)o );
+ pList.replace( i, (SkyPoint*)o );
KPlotObject *po = new KPlotObject( "", "white", KPlotObject::CURVE, 1, KPlotObject::SOLID );
for ( double h=-12.0; h<=12.0; h+=0.5 ) {
@@ -512,7 +512,7 @@ void AVTPlotWidget::mouseMoveEvent( TQMouseEvent *e ) {
int Xcursor = e->x();
int Ycursor = e->y();
- if ( ! checkRect.tqcontains( e->x(), e->y() ) ) {
+ if ( ! checkRect.contains( e->x(), e->y() ) ) {
if ( e->x() < checkRect.left() ) Xcursor = checkRect.left();
if ( e->x() > checkRect.right() ) Xcursor = checkRect.right();
if ( e->y() < checkRect.top() ) Ycursor = checkRect.top();
diff --git a/kstars/kstars/tools/kstarsplotwidget.cpp b/kstars/kstars/tools/kstarsplotwidget.cpp
index d07c3e36..03cc4c38 100644
--- a/kstars/kstars/tools/kstarsplotwidget.cpp
+++ b/kstars/kstars/tools/kstarsplotwidget.cpp
@@ -359,9 +359,9 @@ void KStarsPlotWidget::drawBox( TQPainter *p ) {
case DOUBLE :
{
TQString str = TQString( "%1" ).tqarg( lab, 0, 'g', 2 );
- int idot = str.tqfind( '.' );
+ int idot = str.find( '.' );
if ( idot >= 0 )
- str = str.tqreplace( idot, 1, KGlobal::locale()->decimalSymbol() );
+ str = str.replace( idot, 1, KGlobal::locale()->decimalSymbol() );
if ( px > 0 && px < pW ) {
TQRect r( px - BIGTICKSIZE, pH+BIGTICKSIZE, 2*BIGTICKSIZE, BIGTICKSIZE );
@@ -427,9 +427,9 @@ void KStarsPlotWidget::drawBox( TQPainter *p ) {
case DOUBLE :
{
TQString str = TQString( "%1" ).tqarg( lab, 0, 'g', 2 );
- int idot = str.tqfind( '.' );
+ int idot = str.find( '.' );
if ( idot >= 0 )
- str = str.tqreplace( idot, 1, KGlobal::locale()->decimalSymbol() );
+ str = str.replace( idot, 1, KGlobal::locale()->decimalSymbol() );
if ( py > 0 && py < pH ) {
TQRect r( -2*BIGTICKSIZE, py-SMALLTICKSIZE, 2*BIGTICKSIZE, 2*SMALLTICKSIZE );
@@ -493,9 +493,9 @@ void KStarsPlotWidget::drawBox( TQPainter *p ) {
case DOUBLE :
{
TQString str = TQString( "%1" ).tqarg( lab, 0, 'g', 2 );
- int idot = str.tqfind( '.' );
+ int idot = str.find( '.' );
if ( idot >= 0 )
- str = str.tqreplace( idot, 1, KGlobal::locale()->decimalSymbol() );
+ str = str.replace( idot, 1, KGlobal::locale()->decimalSymbol() );
if ( px > 0 && px < pW ) {
TQRect r( px - BIGTICKSIZE, -2*BIGTICKSIZE, 2*BIGTICKSIZE, BIGTICKSIZE );
@@ -557,9 +557,9 @@ void KStarsPlotWidget::drawBox( TQPainter *p ) {
case DOUBLE :
{
TQString str = TQString( "%1" ).tqarg( lab, 0, 'g', 2 );
- int idot = str.tqfind( '.' );
+ int idot = str.find( '.' );
if ( idot >= 0 )
- str = str.tqreplace( idot, 1, KGlobal::locale()->decimalSymbol() );
+ str = str.replace( idot, 1, KGlobal::locale()->decimalSymbol() );
if ( py > 0 && py < pH ) {
TQRect r( pW + 2*BIGTICKSIZE, py-SMALLTICKSIZE, 2*BIGTICKSIZE, 2*SMALLTICKSIZE );
diff --git a/kstars/kstars/tools/observinglist.cpp b/kstars/kstars/tools/observinglist.cpp
index a50165ac..323d5f62 100644
--- a/kstars/kstars/tools/observinglist.cpp
+++ b/kstars/kstars/tools/observinglist.cpp
@@ -121,7 +121,7 @@ ObservingList::ObservingList( KStars *_ks, TQWidget* tqparent )
ui->NotesEdit->setEnabled( false );
}
-bool ObservingList::tqcontains( const SkyObject *q ) {
+bool ObservingList::contains( const SkyObject *q ) {
for ( SkyObject* o = obsList.first(); o; o = obsList.next() ) {
if ( o == q ) return true;
}
@@ -346,7 +346,7 @@ void ObservingList::slotSlewToObject()
SkyPoint sp;
// Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
- // i.e. the first telescope we tqfind!
+ // i.e. the first telescope we find!
INDIMenu *imenu = ks->getINDIMenu();
diff --git a/kstars/kstars/tools/observinglist.h b/kstars/kstars/tools/observinglist.h
index a1602f1f..70671d48 100644
--- a/kstars/kstars/tools/observinglist.h
+++ b/kstars/kstars/tools/observinglist.h
@@ -71,7 +71,7 @@ public:
/**@return true if the object is in the observing list
*@p o pointer to the object to test.
*/
- bool tqcontains( const SkyObject *o );
+ bool contains( const SkyObject *o );
SkyObject* first() { return obsList.first(); }
SkyObject* next() { return obsList.next(); }
diff --git a/kstars/kstars/tools/obslistwizard.cpp b/kstars/kstars/tools/obslistwizard.cpp
index 9a3c57d8..1e65c24d 100644
--- a/kstars/kstars/tools/obslistwizard.cpp
+++ b/kstars/kstars/tools/obslistwizard.cpp
@@ -195,32 +195,32 @@ void ObsListWizard::slotShowStackWidget( TQListViewItem *i )
if ( i ) {
TQString t = i->text(0);
- if ( t.tqcontains( i18n( "Object type(s)" ) ) ) olw->FilterStack->raiseWidget( olw->ObjTypePage );
- if ( t.tqcontains( i18n( "Region" ) ) ) olw->FilterStack->raiseWidget( olw->RegionPage );
- if ( t.tqcontains( i18n( "In constellation(s)" ) ) ) olw->FilterStack->raiseWidget( olw->ConstellationPage );
- if ( t.tqcontains( i18n( "Circular" ) ) ) olw->FilterStack->raiseWidget( olw->CircRegionPage );
- if ( t.tqcontains( i18n( "Rectangular" ) ) ) olw->FilterStack->raiseWidget( olw->RectRegionPage );
-// if ( t.tqcontains( i18n( "Observable on date" ) ) ) olw->FilterStack->raiseWidget( olw->ObsDatePage );
- if ( t.tqcontains( i18n( "Magnitude limit" ) ) ) olw->FilterStack->raiseWidget( olw->MagLimitPage );
+ if ( t.contains( i18n( "Object type(s)" ) ) ) olw->FilterStack->raiseWidget( olw->ObjTypePage );
+ if ( t.contains( i18n( "Region" ) ) ) olw->FilterStack->raiseWidget( olw->RegionPage );
+ if ( t.contains( i18n( "In constellation(s)" ) ) ) olw->FilterStack->raiseWidget( olw->ConstellationPage );
+ if ( t.contains( i18n( "Circular" ) ) ) olw->FilterStack->raiseWidget( olw->CircRegionPage );
+ if ( t.contains( i18n( "Rectangular" ) ) ) olw->FilterStack->raiseWidget( olw->RectRegionPage );
+// if ( t.contains( i18n( "Observable on date" ) ) ) olw->FilterStack->raiseWidget( olw->ObsDatePage );
+ if ( t.contains( i18n( "Magnitude limit" ) ) ) olw->FilterStack->raiseWidget( olw->MagLimitPage );
}
}
void ObsListWizard::slotDeepSkyButton()
{
olw->TypeList->selectAll( false );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Open Clusters" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Globular Clusters" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Gaseous Nebulae" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Planetary Nebulae" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Galaxies" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Open Clusters" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Globular Clusters" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Gaseous Nebulae" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Planetary Nebulae" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Galaxies" ) ), true );
}
void ObsListWizard::slotSolarSystemButton()
{
olw->TypeList->selectAll( false );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Sun, Moon, Planets" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Comets" ) ), true );
- olw->TypeList->setSelected( olw->TypeList->tqfindItem( i18n( "Asteroids" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Sun, Moon, Planets" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Comets" ) ), true );
+ olw->TypeList->setSelected( olw->TypeList->findItem( i18n( "Asteroids" ) ), true );
}
void ObsListWizard::slotChangeLocation()
@@ -235,23 +235,23 @@ void ObsListWizard::slotChangeLocation()
void ObsListWizard::slotUpdateObjectCount()
{
ObjectCount = 0;
- if ( olw->TypeList->tqfindItem( i18n( "Stars" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Stars" ) )->isSelected() )
ObjectCount += StarCount;
- if ( olw->TypeList->tqfindItem( i18n( "Sun, Moon, Planets" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Sun, Moon, Planets" ) )->isSelected() )
ObjectCount += PlanetCount;
- if ( olw->TypeList->tqfindItem( i18n( "Comets" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Comets" ) )->isSelected() )
ObjectCount += CometCount;
- if ( olw->TypeList->tqfindItem( i18n( "Asteroids" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Asteroids" ) )->isSelected() )
ObjectCount += AsteroidCount;
- if ( olw->TypeList->tqfindItem( i18n( "Galaxies" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Galaxies" ) )->isSelected() )
ObjectCount += GalaxyCount;
- if ( olw->TypeList->tqfindItem( i18n( "Open Clusters" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Open Clusters" ) )->isSelected() )
ObjectCount += OpenClusterCount;
- if ( olw->TypeList->tqfindItem( i18n( "Globular Clusters" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Globular Clusters" ) )->isSelected() )
ObjectCount += GlobClusterCount;
- if ( olw->TypeList->tqfindItem( i18n( "Gaseous Nebulae" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Gaseous Nebulae" ) )->isSelected() )
ObjectCount += GasNebCount;
- if ( olw->TypeList->tqfindItem( i18n( "Planetary Nebulae" ) )->isSelected() )
+ if ( olw->TypeList->findItem( i18n( "Planetary Nebulae" ) )->isSelected() )
ObjectCount += PlanNebCount;
applyFilters( false ); //false = only adjust counts, do not build list
@@ -307,7 +307,7 @@ void ObsListWizard::applyFilters( bool doBuildList )
//Stars
int starIndex(ksw->data()->starList.count());
- if ( olw->TypeList->tqfindItem( i18n( "Stars" ) )->isSelected() ) {
+ if ( olw->TypeList->findItem( i18n( "Stars" ) )->isSelected() ) {
if ( maglimit < 100. ) {
//Stars are sorted by mag, so use binary search algo to find index of faintest mag
int low(0), high(ksw->data()->starList.count()-1), middle;
@@ -338,7 +338,7 @@ void ObsListWizard::applyFilters( bool doBuildList )
}
//Sun, Moon, Planets
- if ( olw->TypeList->tqfindItem( i18n( "Sun, Moon, Planets" ) )->isSelected() ) {
+ if ( olw->TypeList->findItem( i18n( "Sun, Moon, Planets" ) )->isSelected() ) {
applyRegionFilter( (SkyObject*)ksw->data()->PCat->planetSun(), doBuildList );
applyRegionFilter( (SkyObject*)ksw->data()->Moon, doBuildList );
applyRegionFilter( (SkyObject*)ksw->data()->PCat->findByName("Mercury"), doBuildList );
@@ -354,12 +354,12 @@ void ObsListWizard::applyFilters( bool doBuildList )
//Deep sky objects
for ( SkyObject *o = (SkyObject*)(ksw->data()->deepSkyList.first()); o; o = (SkyObject*)(ksw->data()->deepSkyList.next()) ) {
//Skip unselected object types
- if ( (o->type() == SkyObject::STAR || o->type() == SkyObject::CATALOG_STAR) && ! olw->TypeList->tqfindItem( i18n( "Stars" ) )->isSelected() ) continue;
- if ( o->type() == SkyObject::OPEN_CLUSTER && ! olw->TypeList->tqfindItem( i18n( "Open Clusters" ) )->isSelected() ) continue;
- if ( o->type() == SkyObject::GLOBULAR_CLUSTER && ! olw->TypeList->tqfindItem( i18n( "Globular Clusters" ) )->isSelected() ) continue;
- if ( (o->type() == SkyObject::GASEOUS_NEBULA || o->type() == SkyObject::SUPERNOVA_REMNANT) && ! olw->TypeList->tqfindItem( i18n( "Gaseous Nebulae" ) )->isSelected() ) continue;
- if ( o->type() == SkyObject::PLANETARY_NEBULA && ! olw->TypeList->tqfindItem( i18n( "Planetary Nebulae" ) )->isSelected() ) continue;
- if ( o->type() == SkyObject::GALAXY && ! olw->TypeList->tqfindItem( i18n( "Galaxies" ) )->isSelected() ) continue;
+ if ( (o->type() == SkyObject::STAR || o->type() == SkyObject::CATALOG_STAR) && ! olw->TypeList->findItem( i18n( "Stars" ) )->isSelected() ) continue;
+ if ( o->type() == SkyObject::OPEN_CLUSTER && ! olw->TypeList->findItem( i18n( "Open Clusters" ) )->isSelected() ) continue;
+ if ( o->type() == SkyObject::GLOBULAR_CLUSTER && ! olw->TypeList->findItem( i18n( "Globular Clusters" ) )->isSelected() ) continue;
+ if ( (o->type() == SkyObject::GASEOUS_NEBULA || o->type() == SkyObject::SUPERNOVA_REMNANT) && ! olw->TypeList->findItem( i18n( "Gaseous Nebulae" ) )->isSelected() ) continue;
+ if ( o->type() == SkyObject::PLANETARY_NEBULA && ! olw->TypeList->findItem( i18n( "Planetary Nebulae" ) )->isSelected() ) continue;
+ if ( o->type() == SkyObject::GALAXY && ! olw->TypeList->findItem( i18n( "Galaxies" ) )->isSelected() ) continue;
if ( o->type() == SkyObject::TYPE_UNKNOWN ) continue;
if ( olw->SelectByMag->isChecked() ) {
@@ -380,7 +380,7 @@ void ObsListWizard::applyFilters( bool doBuildList )
}
//Comets
- if ( olw->TypeList->tqfindItem( i18n( "Comets" ) )->isSelected() ) {
+ if ( olw->TypeList->findItem( i18n( "Comets" ) )->isSelected() ) {
for ( SkyObject *o = (SkyObject*)(ksw->data()->cometList.first()); o; o = (SkyObject*)(ksw->data()->cometList.next()) ) {
//comets don't have magnitudes at this point, so skip mag check
applyRegionFilter( o, doBuildList );
@@ -388,7 +388,7 @@ void ObsListWizard::applyFilters( bool doBuildList )
}
//Asteroids
- if ( olw->TypeList->tqfindItem( i18n( "Asteroids" ) )->isSelected() ) {
+ if ( olw->TypeList->findItem( i18n( "Asteroids" ) )->isSelected() ) {
for ( SkyObject *o = (SkyObject*)(ksw->data()->asteroidList.first()); o; o = (SkyObject*)(ksw->data()->asteroidList.next()) ) {
if ( olw->SelectByMag->isChecked() ) {
@@ -418,7 +418,7 @@ void ObsListWizard::applyRegionFilter( SkyObject *o, bool doBuildList, bool doAd
//select by constellation
if ( olw->SelectByConstellation->isChecked() ) {
TQString c( o->constellation( ksw->data()->csegmentList, ksw->data()->cnameList ) );
- TQListBoxItem *it = olw->ConstellationList->tqfindItem( c );
+ TQListBoxItem *it = olw->ConstellationList->findItem( c );
if ( it && it->isSelected() ) {
if ( doBuildList ) obsList().append ( o );
diff --git a/kstars/kstars/tools/scriptbuilder.cpp b/kstars/kstars/tools/scriptbuilder.cpp
index 471e50c9..18736f98 100644
--- a/kstars/kstars/tools/scriptbuilder.cpp
+++ b/kstars/kstars/tools/scriptbuilder.cpp
@@ -709,7 +709,7 @@ void ScriptBuilder::initViewOptions() {
while ( !stream.eof() ) {
line = stream.readLine();
- argLoadColorScheme->SchemeList->insertItem( line.left( line.tqfind( ':' ) ) );
+ argLoadColorScheme->SchemeList->insertItem( line.left( line.find( ':' ) ) );
}
file.close();
}
@@ -922,7 +922,7 @@ void ScriptBuilder::writeScript( TQTextStream &ostream ) {
ostream << "#by " << currentAuthor << endl;
ostream << "#last modified: " << KStarsDateTime::tqcurrentDateTime().toString() << endl;
ostream << "#" << endl;
- ostream << "KSTARS=`dcoptqfind -a 'kstars*'`" << endl;
+ ostream << "KSTARS=`dcopfind -a 'kstars*'`" << endl;
ostream << "MAIN=KStarsInterface" << endl;
ostream << "CLOCK=clock#1" << endl;
@@ -946,7 +946,7 @@ void ScriptBuilder::writeScript( TQTextStream &ostream ) {
sf->setINDIProperty("PARK");
}
- if ( sf->argVal(0).tqcontains(" "))
+ if ( sf->argVal(0).contains(" "))
ostream << mainpre << "waitForINDIAction " << "\"" << sf->argVal(0) << "\" " << sf->INDIProperty() << endl;
else
ostream << mainpre << "waitForINDIAction " << sf->argVal(0) << " " << sf->INDIProperty() << endl;
@@ -965,11 +965,11 @@ void ScriptBuilder::readScript( TQTextStream &istream ) {
line = istream.readLine();
//look for name of script
- if ( line.tqcontains( "#KStars DCOP script: " ) )
+ if ( line.contains( "#KStars DCOP script: " ) )
currentScriptName = line.mid( 21 ).stripWhiteSpace();
//look for author of scriptbuilder
- if ( line.tqcontains( "#by " ) )
+ if ( line.contains( "#by " ) )
currentAuthor = line.mid( 4 ).stripWhiteSpace();
//Actual script functions
@@ -977,7 +977,7 @@ void ScriptBuilder::readScript( TQTextStream &istream ) {
//is ClockFunction?
bool clockfcn( false );
- if ( line.tqcontains( "$CLOCK" ) ) clockfcn = true;
+ if ( line.contains( "$CLOCK" ) ) clockfcn = true;
//remove leading dcop prefix
line = line.mid( 20 );
@@ -1369,7 +1369,7 @@ void ScriptBuilder::slotArgWidget() {
} else if ( sf->name() == "loadColorScheme" ) {
sb->ArgStack->raiseWidget( argLoadColorScheme );
- argLoadColorScheme->SchemeList->setCurrentItem( argLoadColorScheme->SchemeList->tqfindItem( sf->argVal(0).remove('\"'), 0 ) );
+ argLoadColorScheme->SchemeList->setCurrentItem( argLoadColorScheme->SchemeList->findItem( sf->argVal(0).remove('\"'), 0 ) );
} else if ( sf->name() == "stop" ) {
sb->ArgStack->raiseWidget( argBlank );
diff --git a/kstars/kstars/tools/scriptfunction.cpp b/kstars/kstars/tools/scriptfunction.cpp
index 4a3b70f2..8b74ab61 100644
--- a/kstars/kstars/tools/scriptfunction.cpp
+++ b/kstars/kstars/tools/scriptfunction.cpp
@@ -90,7 +90,7 @@ ScriptFunction::ScriptFunction( TQString name, TQString desc, bool clockfcn,
//before adding description, replace any '%n' instances with the corresponding
//argument name in color. For now, assume that the %n's occur in order, with no skips.
//Also assume that '%' is *only* used to indicate argument instances
- int narg = desc.tqcontains( '%' );
+ int narg = desc.contains( '%' );
switch (narg ) {
case 1:
Description += desc.tqarg( paramStyle.tqarg( an1 ) );
@@ -206,7 +206,7 @@ TQString ScriptFunction::scriptLine() const {
unsigned int i=0;
while ( ! ArgName[i].isEmpty() && i < 6 ) {
// Wrap arg in quotes if it contains a space
- if ( ArgVal[i].tqcontains(" ") ) {
+ if ( ArgVal[i].contains(" ") ) {
out += " \"" + ArgVal[i] + "\"";
} else {
out += " " + ArgVal[i];
diff --git a/kstars/kstars/detaildialog.cpp b/kstars/kstars/detaildialog.cpp
index 91ac6a79..3f06da87 100644
--- a/kstars/kstars/detaildialog.cpp
+++ b/kstars/kstars/detaildialog.cpp
@@ -313,7 +313,7 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
//because we don't want a thousands-place separator!
TQString sEpoch = TQString::number( ut.epoch(), 'f', 1 );
//Replace the decimal point with localized decimal symbol
- sEpoch.tqreplace( ".", KGlobal::locale()->decimalSymbol() );
+ sEpoch.replace( ".", KGlobal::locale()->decimalSymbol() );
Pos->RALabel->setText( i18n( "RA (%1):" ).tqarg( sEpoch ) );
Pos->DecLabel->setText( i18n( "Dec (%1):" ).tqarg( sEpoch ) );
@@ -706,9 +706,9 @@ bool DetailDialog::verifyUserData(int type)
for (i=0; i<dataList.count(); i++)
{
line = dataList[i];
- name = line.mid( 0, line.tqfind(':') );
- sub = line.mid( line.tqfind(':')+1 );
- title = sub.mid( 0, sub.tqfind(':') );
+ name = line.mid( 0, line.find(':') );
+ sub = line.mid( line.find(':')+1 );
+ title = sub.mid( 0, sub.find(':') );
if (name == selectedObject->name() && title == currentItemTitle)
{
ObjectFound = true;
@@ -723,9 +723,9 @@ bool DetailDialog::verifyUserData(int type)
for (i=0; i<dataList.count(); i++)
{
line = dataList[i];
- name = line.mid( 0, line.tqfind(':') );
- sub = line.mid( line.tqfind(':')+1 );
- title = sub.mid( 0, sub.tqfind(':') );
+ name = line.mid( 0, line.find(':') );
+ sub = line.mid( line.find(':')+1 );
+ title = sub.mid( 0, sub.find(':') );
if (name == selectedObject->name() && title == currentItemTitle)
{
ObjectFound = true;
@@ -845,13 +845,13 @@ TQString DetailDialog::parseADVData(TQString link)
TQString subLink;
int index;
- if ( (index = link.tqfind("KSOBJ")) != -1)
+ if ( (index = link.find("KSOBJ")) != -1)
{
link.remove(index, 5);
link = link.insert(index, selectedObject->name());
}
- if ( (index = link.tqfind("KSRA")) != -1)
+ if ( (index = link.find("KSRA")) != -1)
{
link.remove(index, 4);
subLink = TQString().sprintf("%02d%02d%02d", selectedObject->ra0()->hour(), selectedObject->ra0()->minute(), selectedObject->ra0()->second());
@@ -860,7 +860,7 @@ TQString DetailDialog::parseADVData(TQString link)
link = link.insert(index, subLink);
}
- if ( (index = link.tqfind("KSDEC")) != -1)
+ if ( (index = link.find("KSDEC")) != -1)
{
link.remove(index, 5);
if (selectedObject->dec()->degree() < 0)
@@ -906,7 +906,7 @@ void DetailDialog::centerTelescope()
SkyPoint sp;
// Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
// i.e. the first telescope we tqfind!
INDIMenu *imenu = ksw->getINDIMenu();
@@ -1040,7 +1040,7 @@ void DetailDialog::showThumbnail() {
//If no image found, load "no image" image
//If that isn't found, make it blank.
TQFile file;
- TQString fname = "thumb-" + selectedObject->name().lower().tqreplace( TQRegExp(" "), "" ) + ".png";
+ TQString fname = "thumb-" + selectedObject->name().lower().replace( TQRegExp(" "), "" ) + ".png";
if ( KSUtils::openDataFile( file, fname ) ) {
file.close();
Thumbnail->load( file.name(), "PNG" );
@@ -1060,7 +1060,7 @@ void DetailDialog::updateThumbnail() {
if ( tp.exec() == TQDialog::Accepted ) {
TQString fname = locateLocal( "appdata", "thumb-"
- + selectedObject->name().lower().tqreplace( TQRegExp(" "), "" ) + ".png" );
+ + selectedObject->name().lower().replace( TQRegExp(" "), "" ) + ".png" );
Data->Image->setPixmap( *(tp.image()) );
@@ -906,7 +906,7 @@ void DetailDialog::centerTelescope()
SkyPoint sp;
// Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
- // i.e. the first telescope we tqfind!
+ // i.e. the first telescope we find!
INDIMenu *imenu = ksw->getINDIMenu();
diff --git a/kstars/kstars/indidevice.cpp b/kstars/kstars/indidevice.cpp
index 962192cb..350d7d09 100644
--- a/kstars/kstars/indidevice.cpp
+++ b/kstars/kstars/indidevice.cpp
@@ -521,7 +521,7 @@ int INDI_D::processBlob(INDI_E *blobEL, XMLEle *ep, char errmsg[])
return (-1);
}
- iscomp = (dataFormat.tqfind(".z") != -1);
+ iscomp = (dataFormat.find(".z") != -1);
dataFormat.remove(".z");
@@ -679,7 +679,7 @@ INDI_G * INDI_D::findGroup (TQString grouptag, int create, char errmsg[])
}
/* tqfind "perm" attribute in root, crack and set *pp.
* return 0 if ok else -1 with excuse in errmsg[]
*/
@@ -679,7 +679,7 @@ INDI_G * INDI_D::findGroup (TQString grouptag, int create, char errmsg[])
}
-/* tqfind "perm" attribute in root, crack and set *pp.
+/* find "perm" attribute in root, crack and set *pp.
* return 0 if ok else -1 with excuse in errmsg[]
*/
diff --git a/kstars/kstars/kstarsdata.cpp b/kstars/kstars/kstarsdata.cpp
index d12ddca1..e4f557f4 100644
--- a/kstars/kstars/kstarsdata.cpp
+++ b/kstars/kstars/kstarsdata.cpp
@@ -226,17 +226,17 @@ bool KStarsData::readADVTreeData(void)
else
{
- Name = Line.mid(0, Line.tqfind(":"));
- Link = Line.mid(Line.tqfind(":") + 1);
+ Name = Line.mid(0, Line.find(":"));
+ Link = Line.mid(Line.find(":") + 1);
// Link is empty, using Interface instead
if (Link.isEmpty())
{
Link = Interface;
subName = Name;
- interfaceIndex = Link.tqfind("KSINTERFACE");
+ interfaceIndex = Link.find("KSINTERFACE");
Link.remove(interfaceIndex, 11);
- Link = Link.insert(interfaceIndex, subName.tqreplace( TQRegExp(" "), "+"));
+ Link = Link.insert(interfaceIndex, subName.replace( TQRegExp(" "), "+"));
}
@@ -664,9 +664,9 @@ void KStarsData::processStar( TQString *line, bool reloadMode ) {
//parse name(s)
name = line->mid( 72 ).stripWhiteSpace(); //the rest of the line
- if (name.tqcontains( ':' )) { //genetive form exists
- gname = name.mid( name.tqfind(':')+1 ).stripWhiteSpace();
- name = name.mid( 0, name.tqfind(':') ).stripWhiteSpace();
+ if (name.contains( ':' )) { //genetive form exists
+ gname = name.mid( name.find(':')+1 ).stripWhiteSpace();
+ name = name.mid( 0, name.find(':') ).stripWhiteSpace();
}
// HEV: look up star name in internationalization filesource
@@ -964,14 +964,14 @@ bool KStarsData::openURLFile(TQString urlfile, TQFile & file) {
TQString line = gStream.readLine();
//If global-file line begins with "XXX:" then this line should be removed from the local file.
- if ( line.left( 4 ) == "XXX:" && urlData.tqcontains( line.mid( 4 ) ) ) {
- urlData.remove( urlData.tqfind( line.mid( 4 ) ) );
+ if ( line.left( 4 ) == "XXX:" && urlData.contains( line.mid( 4 ) ) ) {
+ urlData.remove( urlData.find( line.mid( 4 ) ) );
} else {
//does local file contain the current global file line, up to second ':' ?
bool linefound( false );
for ( unsigned int j=0; j< urlData.count(); ++j ) {
- if ( urlData[j].tqcontains( line.left( line.tqfind( ':', line.tqfind( ':' ) + 1 ) ) ) ) {
+ if ( urlData[j].contains( line.left( line.find( ':', line.find( ':' ) + 1 ) ) ) ) {
//replace line in urlData with its equivalent in the newer global file.
urlData.remove( urlData.at(j) );
urlData.insert( urlData.at(j), line );
@@ -1047,21 +1047,21 @@ bool KStarsData::readUserLog(void)
while (!buffer.isEmpty()) {
int startIndex, endIndex;
- startIndex = buffer.tqfind("[KSLABEL:");
+ startIndex = buffer.find("[KSLABEL:");
sub = buffer.mid(startIndex);
- endIndex = sub.tqfind("[KSLogEnd]");
+ endIndex = sub.find("[KSLogEnd]");
// Read name after KSLABEL identifer
- uint uiFirstNewline = sub.tqfind("\n", startIndex + 9);
- name = sub.mid(startIndex + 9, sub.tqfindRev( "]", uiFirstNewline ) - (startIndex + 9) );
+ uint uiFirstNewline = sub.find("\n", startIndex + 9);
+ name = sub.mid(startIndex + 9, sub.findRev( "]", uiFirstNewline ) - (startIndex + 9) );
// Read data and skip new line
data = sub.mid( uiFirstNewline + 1, endIndex - (uiFirstNewline + 1));
buffer = buffer.mid(endIndex + 11);
//Find the sky object named 'name'.
//Note that ObjectNameList::tqfind() looks for the ascii representation
//of star genetive names, so stars are identified that way in the user log.
- SkyObjectName *sonm = ObjNames.tqfind(name);
+ SkyObjectName *sonm = ObjNames.find(name);
if (sonm == 0) {
kdWarning() << k_funcinfo << name << " not found" << endl;
} else {
@@ -1084,12 +1084,12 @@ bool KStarsData::readURLData( TQString urlfile, int type, bool deepOnly ) {
//ignore comment lines
if ( line.left(1) != "#" ) {
- TQString name = line.mid( 0, line.tqfind(':') );
- TQString sub = line.mid( line.tqfind(':')+1 );
- TQString title = sub.mid( 0, sub.tqfind(':') );
- TQString url = sub.mid( sub.tqfind(':')+1 );
+ TQString name = line.mid( 0, line.find(':') );
+ TQString sub = line.mid( line.find(':')+1 );
+ TQString title = sub.mid( 0, sub.find(':') );
+ TQString url = sub.mid( sub.find(':')+1 );
- SkyObjectName *sonm = ObjNames.tqfind(name);
+ SkyObjectName *sonm = ObjNames.find(name);
if (sonm == 0) {
kdWarning() << k_funcinfo << name << " not found" << endl;
@@ -1196,7 +1196,7 @@ CustomCatalog* KStarsData::createCustomCatalog( TQString filename, bool showerrs
//Now, if one of the columns is the "Name" field, the name may contain spaces.
//In this case, the name field will need to be surrounded by quotes.
//Check for this, and adjust the d list accordingly
- int iname = Columns.tqfindIndex( "Nm" );
+ int iname = Columns.findIndex( "Nm" );
if ( iname >= 0 && d[iname].left(1) == "\"" ) { //multi-word name in quotes
d[iname] = d[iname].mid(1); //remove leading quote
//It's possible that the name is one word, but still in quotes
@@ -1388,13 +1388,13 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
TQString d( *it ); //current data line
if ( d.left(1) != "#" ) break; //no longer in header!
- int iname = d.tqfind( "# Name: " );
- int iprefix = d.tqfind( "# Prefix: " );
- int icolor = d.tqfind( "# Color: " );
- int iepoch = d.tqfind( "# Epoch: " );
+ int iname = d.find( "# Name: " );
+ int iprefix = d.find( "# Prefix: " );
+ int icolor = d.find( "# Color: " );
+ int iepoch = d.find( "# Epoch: " );
if ( iname == 0 ) { //line contains catalog name
- iname = d.tqfind(":")+2;
+ iname = d.find(":")+2;
if ( CatalogName.isEmpty() ) {
CatalogName = d.mid( iname );
} else { //duplicate name in header
@@ -1403,7 +1403,7 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
i18n( "Extra Name field in header: %1. Will be ignored" ).tqarg( d.mid(iname) ) );
}
} else if ( iprefix == 0 ) { //line contains catalog prefix
- iprefix = d.tqfind(":")+2;
+ iprefix = d.find(":")+2;
if ( CatalogPrefix.isEmpty() ) {
CatalogPrefix = d.mid( iprefix );
} else { //duplicate prefix in header
@@ -1412,7 +1412,7 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
i18n( "Extra Prefix field in header: %1. Will be ignored" ).tqarg( d.mid(iprefix) ) );
}
} else if ( icolor == 0 ) { //line contains catalog prefix
- icolor = d.tqfind(":")+2;
+ icolor = d.find(":")+2;
if ( CatalogColor.isEmpty() ) {
CatalogColor = d.mid( icolor );
} else { //duplicate prefix in header
@@ -1421,7 +1421,7 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
i18n( "Extra Color field in header: %1. Will be ignored" ).tqarg( d.mid(icolor) ) );
}
} else if ( iepoch == 0 ) { //line contains catalog epoch
- iepoch = d.tqfind(":")+2;
+ iepoch = d.find(":")+2;
if ( CatalogEpoch == 0. ) {
bool ok( false );
CatalogEpoch = d.mid( iepoch ).toFloat( &ok );
@@ -1438,7 +1438,7 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
}
} else if ( ! foundDataColumns ) { //don't try to parse data column descriptors if we already found them
//Chomp off leading "#" character
- d = d.tqreplace( TQRegExp( "#" ), "" );
+ d = d.replace( TQRegExp( "#" ), "" );
TQStringList fields = TQStringList::split( " ", d ); //split on whitespace
@@ -1452,17 +1452,17 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
for ( ; itf != itfEnd; itf++ ) {
TQString s( *itf );
- if ( master.tqcontains( s ) ) {
+ if ( master.contains( s ) ) {
//add the data field
Columns.append( s );
// remove the field from the master list and inc the
// count of "good" columns (unless field is "Ignore")
if ( s != "Ig" ) {
- master.remove( master.tqfind( s ) );
+ master.remove( master.find( s ) );
ncol++;
}
- } else if ( fields.tqcontains( s ) ) { //duplicate field
+ } else if ( fields.contains( s ) ) { //duplicate field
fields.append( "Ig" ); //skip this column
if ( showerrs )
errs.append( i18n( "Parsing header: " ) +
@@ -1514,7 +1514,7 @@ bool KStarsData::parseCustomDataHeader( TQStringList lines, TQStringList &Column
}
//the it iterator now points to the first line past the header
- iStart = lines.tqfindIndex( TQString( *it ) );
+ iStart = lines.findIndex( TQString( *it ) );
return true;
}
}
@@ -1646,10 +1646,10 @@ bool KStarsData::readTimeZoneRulebook( void ) {
if ( line.left(1) != "#" && line.length() ) { //ignore commented and blank lines
TQStringList fields = TQStringList::split( " ", line );
id = fields[0];
- TQTime stime = TQTime( fields[3].left( fields[3].tqfind(':')).toInt() ,
- fields[3].mid( fields[3].tqfind(':')+1, fields[3].length()).toInt() );
- TQTime rtime = TQTime( fields[6].left( fields[6].tqfind(':')).toInt(),
- fields[6].mid( fields[6].tqfind(':')+1, fields[6].length()).toInt() );
+ TQTime stime = TQTime( fields[3].left( fields[3].find(':')).toInt() ,
+ fields[3].mid( fields[3].find(':')+1, fields[3].length()).toInt() );
+ TQTime rtime = TQTime( fields[6].left( fields[6].find(':')).toInt(),
+ fields[6].mid( fields[6].find(':')+1, fields[6].length()).toInt() );
Rulebook[ id ] = TimeZoneRule( fields[1], fields[2], stime, fields[4], fields[5], rtime );
}
@@ -2236,7 +2236,7 @@ void KStarsData::setFullTimeUpdate() {
}
void KStarsData::setLocationFromOptions() {
- TQMap<TQString, TimeZoneRule>::Iterator it = Rulebook.tqfind( Options::dST() );
+ TQMap<TQString, TimeZoneRule>::Iterator it = Rulebook.find( Options::dST() );
setLocation( GeoLocation ( Options::longitude(), Options::latitude(),
Options::cityName(), Options::provinceName(), Options::countryName(),
Options::timeZone(), &(it.data()), 4, Options::elevation() ) );
@@ -1047,21 +1047,21 @@ bool KStarsData::readUserLog(void)
buffer = buffer.mid(endIndex + 11);
//Find the sky object named 'name'.
- //Note that ObjectNameList::tqfind() looks for the ascii representation
+ //Note that ObjectNameList::find() looks for the ascii representation
//of star genetive names, so stars are identified that way in the user log.
diff --git a/kstars/kstars/objectnamelist.h b/kstars/kstars/objectnamelist.h
index ea19f621..63f5349a 100644
--- a/kstars/kstars/objectnamelist.h
+++ b/kstars/kstars/objectnamelist.h
@@ -87,7 +87,7 @@ class ObjectNameList {
*@param name name of object to find.
*@return pointer to object with the given name
*/
- SkyObjectName* tqfind(const TQString &name = TQString());
+ SkyObjectName* find(const TQString &name = TQString());
/**@short remove the named object from the list.
*@param name the name of the object to be removed.
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
*It's needed for tqfind(). first() and tqfind() call this function.
*/
void sort();
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
- *It's needed for tqfind(). first() and tqfind() call this function.
+ *It's needed for find(). first() and find() call this function.
*/
void sort();
diff --git a/kstars/kstars/skyobject.cpp b/kstars/kstars/skyobject.cpp
index 18decc7c..03f973fe 100644
--- a/kstars/kstars/skyobject.cpp
+++ b/kstars/kstars/skyobject.cpp
@@ -205,7 +205,7 @@ TQTime SkyObject::transitTimeUT( const KStarsDateTime &dt, const GeoLocation *ge
//dt0 is the first guess at the transit time.
KStarsDateTime dt0 = dt.addSecs( dSec );
//recompute object's position at UT0 and then tqfind
//transit time of this refined position
SkyPoint sp = recomputeCoords( dt0, geo );
const dms *ram = sp.ra0();
@@ -342,11 +342,11 @@ TQString SkyObject::messageFromTitle( const TQString &imageTitle ) {
TQString message = imageTitle;
//HST Image
- if ( imageTitle == i18n( "Show HST Image" ) || imageTitle.tqcontains("HST") ) {
+ if ( imageTitle == i18n( "Show HST Image" ) || imageTitle.contains("HST") ) {
message = i18n( "%1: Hubble Space Telescope, operated by STScI for NASA [public domain]" ).tqarg( longname() );
//Spitzer Image
- } else if ( imageTitle.tqcontains( i18n( "Show Spitzer Image" ) ) ) {
+ } else if ( imageTitle.contains( i18n( "Show Spitzer Image" ) ) ) {
message = i18n( "%1: Spitzer Space Telescope, courtesy NASA/JPL-Caltech [public domain]" ).tqarg( longname() );
//SEDS Image
@@ -358,16 +358,16 @@ TQString SkyObject::messageFromTitle( const TQString &imageTitle ) {
message = i18n( "%1: Advanced Observing Program at Kitt Peak National Observatory [free for non-commercial use; no physical reproductions]" ).tqarg( longname() );
//NOAO Image
- } else if ( imageTitle.tqcontains( i18n( "Show NOAO Image" ) ) ) {
+ } else if ( imageTitle.contains( i18n( "Show NOAO Image" ) ) ) {
message = i18n( "%1: National Optical Astronomy Observatories and AURA [free for non-commercial use]" ).tqarg( longname() );
//VLT Image
- } else if ( imageTitle.tqcontains( "VLT" ) ) {
+ } else if ( imageTitle.contains( "VLT" ) ) {
message = i18n( "%1: Very Large Telescope, operated by the European Southern Observatory [free for non-commercial use; no reproductions]" ).tqarg( longname() );
//All others
} else if ( imageTitle.startsWith( i18n( "Show" ) ) ) {
- message = imageTitle.mid( imageTitle.tqfind( " " ) + 1 ); //eat first word, "Show"
+ message = imageTitle.mid( imageTitle.find( " " ) + 1 ); //eat first word, "Show"
message = longname() + ": " + message;
}
@@ -408,9 +408,9 @@ void SkyObject::saveUserLog( const TQString &newLog ) {
int startIndex, endIndex;
TQString sub;
- startIndex = logs.tqfind(KSLabel);
+ startIndex = logs.find(KSLabel);
sub = logs.mid (startIndex);
- endIndex = sub.tqfind("[KSLogEnd]");
+ endIndex = sub.find("[KSLogEnd]");
logs.remove(startIndex, endIndex + 11);
}
@@ -205,7 +205,7 @@ TQTime SkyObject::transitTimeUT( const KStarsDateTime &dt, const GeoLocation *ge
//dt0 is the first guess at the transit time.
KStarsDateTime dt0 = dt.addSecs( dSec );
- //recompute object's position at UT0 and then tqfind
+ //recompute object's position at UT0 and then find
//transit time of this refined position
SkyPoint sp = recomputeCoords( dt0, geo );